/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.books.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for ReadingPosition.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Books API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ReadingPosition extends GenericJson {

  /**
   * Position in an EPUB as a CFI.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String epubCfiPosition;

  /**
   * Position in a volume for image-based content.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String gbImagePosition;

  /**
   * Position in a volume for text-based content.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String gbTextPosition;

  /**
   * Resource type for a reading position.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Position in a PDF file.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String pdfPosition;

  /**
   * Timestamp when this reading position was last updated (formatted UTC timestamp with millisecond
   * resolution).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * Volume id associated with this reading position.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String volumeId;

  /**
   * Position in an EPUB as a CFI.
   * The value returned may be {@code null}.
   */
  public String getEpubCfiPosition() {
    return epubCfiPosition;
  }

  /**
   * Position in an EPUB as a CFI.
   * The value set may be {@code null}.
   */
  public ReadingPosition setEpubCfiPosition(String epubCfiPosition) {
    this.epubCfiPosition = epubCfiPosition;
    return this;
  }

  /**
   * Position in a volume for image-based content.
   * The value returned may be {@code null}.
   */
  public String getGbImagePosition() {
    return gbImagePosition;
  }

  /**
   * Position in a volume for image-based content.
   * The value set may be {@code null}.
   */
  public ReadingPosition setGbImagePosition(String gbImagePosition) {
    this.gbImagePosition = gbImagePosition;
    return this;
  }

  /**
   * Position in a volume for text-based content.
   * The value returned may be {@code null}.
   */
  public String getGbTextPosition() {
    return gbTextPosition;
  }

  /**
   * Position in a volume for text-based content.
   * The value set may be {@code null}.
   */
  public ReadingPosition setGbTextPosition(String gbTextPosition) {
    this.gbTextPosition = gbTextPosition;
    return this;
  }

  /**
   * Resource type for a reading position.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type for a reading position.
   * The value set may be {@code null}.
   */
  public ReadingPosition setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Position in a PDF file.
   * The value returned may be {@code null}.
   */
  public String getPdfPosition() {
    return pdfPosition;
  }

  /**
   * Position in a PDF file.
   * The value set may be {@code null}.
   */
  public ReadingPosition setPdfPosition(String pdfPosition) {
    this.pdfPosition = pdfPosition;
    return this;
  }

  /**
   * Timestamp when this reading position was last updated (formatted UTC timestamp with millisecond
   * resolution).
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * Timestamp when this reading position was last updated (formatted UTC timestamp with millisecond
   * resolution).
   * The value set may be {@code null}.
   */
  public ReadingPosition setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * Volume id associated with this reading position.
   * The value returned may be {@code null}.
   */
  public String getVolumeId() {
    return volumeId;
  }

  /**
   * Volume id associated with this reading position.
   * The value set may be {@code null}.
   */
  public ReadingPosition setVolumeId(String volumeId) {
    this.volumeId = volumeId;
    return this;
  }

}
