/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.books.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Volume.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Books API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Volume extends GenericJson {

  /**
   * Any information about a volume related to reading or obtaining that volume text. This
   * information can depend on country (books may be public domain in one country but not in
   * another, e.g.).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private AccessInfo accessInfo;

  /**
   * Opaque identifier for a specific version of a volume resource. (In LITE projection)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * Unique identifier for a volume. (In LITE projection.)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Resource type for a volume. (In LITE projection.)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * What layers exist in this volume and high level information about them.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private LayerInfo layerInfo;

  /**
   * Recommendation related information for this volume.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private RecommendedInfo recommendedInfo;

  /**
   * Any information about a volume related to the eBookstore and/or purchaseability. This
   * information can depend on the country where the request originates from (i.e. books may not be
   * for sale in certain countries).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SaleInfo saleInfo;

  /**
   * Search result information related to this volume.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SearchInfo searchInfo;

  /**
   * URL to this resource. (In LITE projection.)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * User specific information related to this volume. (e.g. page this user last read or whether
   * they purchased this book)
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private UserInfo userInfo;

  /**
   * General volume information.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private VolumeInfo volumeInfo;

  /**
   * Any information about a volume related to reading or obtaining that volume text. This
   * information can depend on country (books may be public domain in one country but not in
   * another, e.g.).
   * The value returned may be {@code null}.
   */
  public AccessInfo getAccessInfo() {
    return accessInfo;
  }

  /**
   * Any information about a volume related to reading or obtaining that volume text. This
   * information can depend on country (books may be public domain in one country but not in
   * another, e.g.).
   * The value set may be {@code null}.
   */
  public Volume setAccessInfo(AccessInfo accessInfo) {
    this.accessInfo = accessInfo;
    return this;
  }

  /**
   * Opaque identifier for a specific version of a volume resource. (In LITE projection)
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Opaque identifier for a specific version of a volume resource. (In LITE projection)
   * The value set may be {@code null}.
   */
  public Volume setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * Unique identifier for a volume. (In LITE projection.)
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Unique identifier for a volume. (In LITE projection.)
   * The value set may be {@code null}.
   */
  public Volume setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * Resource type for a volume. (In LITE projection.)
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type for a volume. (In LITE projection.)
   * The value set may be {@code null}.
   */
  public Volume setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * What layers exist in this volume and high level information about them.
   * The value returned may be {@code null}.
   */
  public LayerInfo getLayerInfo() {
    return layerInfo;
  }

  /**
   * What layers exist in this volume and high level information about them.
   * The value set may be {@code null}.
   */
  public Volume setLayerInfo(LayerInfo layerInfo) {
    this.layerInfo = layerInfo;
    return this;
  }

  /**
   * Recommendation related information for this volume.
   * The value returned may be {@code null}.
   */
  public RecommendedInfo getRecommendedInfo() {
    return recommendedInfo;
  }

  /**
   * Recommendation related information for this volume.
   * The value set may be {@code null}.
   */
  public Volume setRecommendedInfo(RecommendedInfo recommendedInfo) {
    this.recommendedInfo = recommendedInfo;
    return this;
  }

  /**
   * Any information about a volume related to the eBookstore and/or purchaseability. This
   * information can depend on the country where the request originates from (i.e. books may not be
   * for sale in certain countries).
   * The value returned may be {@code null}.
   */
  public SaleInfo getSaleInfo() {
    return saleInfo;
  }

  /**
   * Any information about a volume related to the eBookstore and/or purchaseability. This
   * information can depend on the country where the request originates from (i.e. books may not be
   * for sale in certain countries).
   * The value set may be {@code null}.
   */
  public Volume setSaleInfo(SaleInfo saleInfo) {
    this.saleInfo = saleInfo;
    return this;
  }

  /**
   * Search result information related to this volume.
   * The value returned may be {@code null}.
   */
  public SearchInfo getSearchInfo() {
    return searchInfo;
  }

  /**
   * Search result information related to this volume.
   * The value set may be {@code null}.
   */
  public Volume setSearchInfo(SearchInfo searchInfo) {
    this.searchInfo = searchInfo;
    return this;
  }

  /**
   * URL to this resource. (In LITE projection.)
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * URL to this resource. (In LITE projection.)
   * The value set may be {@code null}.
   */
  public Volume setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * User specific information related to this volume. (e.g. page this user last read or whether
   * they purchased this book)
   * The value returned may be {@code null}.
   */
  public UserInfo getUserInfo() {
    return userInfo;
  }

  /**
   * User specific information related to this volume. (e.g. page this user last read or whether
   * they purchased this book)
   * The value set may be {@code null}.
   */
  public Volume setUserInfo(UserInfo userInfo) {
    this.userInfo = userInfo;
    return this;
  }

  /**
   * General volume information.
   * The value returned may be {@code null}.
   */
  public VolumeInfo getVolumeInfo() {
    return volumeInfo;
  }

  /**
   * General volume information.
   * The value set may be {@code null}.
   */
  public Volume setVolumeInfo(VolumeInfo volumeInfo) {
    this.volumeInfo = volumeInfo;
    return this;
  }

  /**
   * Any information about a volume related to reading or obtaining that volume text. This information
   * can depend on country (books may be public domain in one country but not in another, e.g.).
   */
  public static final class AccessInfo extends GenericJson {

    /**
     * Combines the access and viewability of this volume into a single status field for this user.
     * Values can be FULL_PURCHASED, FULL_PUBLIC_DOMAIN, SAMPLE or NONE. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String accessViewStatus;

    /**
     * The two-letter ISO_3166-1 country code for which this access information is valid. (In LITE
     * projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String country;

    /**
     * Information about a volume's download license access restrictions.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private DownloadAccessRestriction downloadAccess;

    /**
     * Whether this volume can be embedded in a viewport using the Embedded Viewer API.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean embeddable;

    /**
     * Information about epub content. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Epub epub;

    /**
     * Information about pdf content. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Pdf pdf;

    /**
     * Whether or not this book is public domain in the country listed above.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean publicDomain;

    /**
     * Whether text-to-speech is permitted for this volume. Values can be ALLOWED,
     * ALLOWED_FOR_ACCESSIBILITY, or NOT_ALLOWED.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String textToSpeechPermission;

    /**
     * For ordered but not yet processed orders, we give a URL that can be used to go to the
     * appropriate Google Wallet page.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String viewOrderUrl;

    /**
     * The read access of a volume. Possible values are PARTIAL, ALL_PAGES, NO_PAGES or UNKNOWN. This
     * value depends on the country listed above. A value of PARTIAL means that the publisher has
     * allowed some portion of the volume to be viewed publicly, without purchase. This can apply to
     * eBooks as well as non-eBooks. Public domain books will always have a value of ALL_PAGES.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String viewability;

    /**
     * URL to read this volume on the Google Books site. Link will not allow users to read non-
     * viewable volumes.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String webReaderLink;

    /**
     * Combines the access and viewability of this volume into a single status field for this user.
     * Values can be FULL_PURCHASED, FULL_PUBLIC_DOMAIN, SAMPLE or NONE. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public String getAccessViewStatus() {
      return accessViewStatus;
    }

    /**
     * Combines the access and viewability of this volume into a single status field for this user.
     * Values can be FULL_PURCHASED, FULL_PUBLIC_DOMAIN, SAMPLE or NONE. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public AccessInfo setAccessViewStatus(String accessViewStatus) {
      this.accessViewStatus = accessViewStatus;
      return this;
    }

    /**
     * The two-letter ISO_3166-1 country code for which this access information is valid. (In LITE
     * projection.)
     * The value returned may be {@code null}.
     */
    public String getCountry() {
      return country;
    }

    /**
     * The two-letter ISO_3166-1 country code for which this access information is valid. (In LITE
     * projection.)
     * The value set may be {@code null}.
     */
    public AccessInfo setCountry(String country) {
      this.country = country;
      return this;
    }

    /**
     * Information about a volume's download license access restrictions.
     * The value returned may be {@code null}.
     */
    public DownloadAccessRestriction getDownloadAccess() {
      return downloadAccess;
    }

    /**
     * Information about a volume's download license access restrictions.
     * The value set may be {@code null}.
     */
    public AccessInfo setDownloadAccess(DownloadAccessRestriction downloadAccess) {
      this.downloadAccess = downloadAccess;
      return this;
    }

    /**
     * Whether this volume can be embedded in a viewport using the Embedded Viewer API.
     * The value returned may be {@code null}.
     */
    public Boolean getEmbeddable() {
      return embeddable;
    }

    /**
     * Whether this volume can be embedded in a viewport using the Embedded Viewer API.
     * The value set may be {@code null}.
     */
    public AccessInfo setEmbeddable(Boolean embeddable) {
      this.embeddable = embeddable;
      return this;
    }

    /**
     * Information about epub content. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public Epub getEpub() {
      return epub;
    }

    /**
     * Information about epub content. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public AccessInfo setEpub(Epub epub) {
      this.epub = epub;
      return this;
    }

    /**
     * Information about pdf content. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public Pdf getPdf() {
      return pdf;
    }

    /**
     * Information about pdf content. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public AccessInfo setPdf(Pdf pdf) {
      this.pdf = pdf;
      return this;
    }

    /**
     * Whether or not this book is public domain in the country listed above.
     * The value returned may be {@code null}.
     */
    public Boolean getPublicDomain() {
      return publicDomain;
    }

    /**
     * Whether or not this book is public domain in the country listed above.
     * The value set may be {@code null}.
     */
    public AccessInfo setPublicDomain(Boolean publicDomain) {
      this.publicDomain = publicDomain;
      return this;
    }

    /**
     * Whether text-to-speech is permitted for this volume. Values can be ALLOWED,
     * ALLOWED_FOR_ACCESSIBILITY, or NOT_ALLOWED.
     * The value returned may be {@code null}.
     */
    public String getTextToSpeechPermission() {
      return textToSpeechPermission;
    }

    /**
     * Whether text-to-speech is permitted for this volume. Values can be ALLOWED,
     * ALLOWED_FOR_ACCESSIBILITY, or NOT_ALLOWED.
     * The value set may be {@code null}.
     */
    public AccessInfo setTextToSpeechPermission(String textToSpeechPermission) {
      this.textToSpeechPermission = textToSpeechPermission;
      return this;
    }

    /**
     * For ordered but not yet processed orders, we give a URL that can be used to go to the
     * appropriate Google Wallet page.
     * The value returned may be {@code null}.
     */
    public String getViewOrderUrl() {
      return viewOrderUrl;
    }

    /**
     * For ordered but not yet processed orders, we give a URL that can be used to go to the
     * appropriate Google Wallet page.
     * The value set may be {@code null}.
     */
    public AccessInfo setViewOrderUrl(String viewOrderUrl) {
      this.viewOrderUrl = viewOrderUrl;
      return this;
    }

    /**
     * The read access of a volume. Possible values are PARTIAL, ALL_PAGES, NO_PAGES or UNKNOWN. This
     * value depends on the country listed above. A value of PARTIAL means that the publisher has
     * allowed some portion of the volume to be viewed publicly, without purchase. This can apply to
     * eBooks as well as non-eBooks. Public domain books will always have a value of ALL_PAGES.
     * The value returned may be {@code null}.
     */
    public String getViewability() {
      return viewability;
    }

    /**
     * The read access of a volume. Possible values are PARTIAL, ALL_PAGES, NO_PAGES or UNKNOWN. This
     * value depends on the country listed above. A value of PARTIAL means that the publisher has
     * allowed some portion of the volume to be viewed publicly, without purchase. This can apply to
     * eBooks as well as non-eBooks. Public domain books will always have a value of ALL_PAGES.
     * The value set may be {@code null}.
     */
    public AccessInfo setViewability(String viewability) {
      this.viewability = viewability;
      return this;
    }

    /**
     * URL to read this volume on the Google Books site. Link will not allow users to read non-
     * viewable volumes.
     * The value returned may be {@code null}.
     */
    public String getWebReaderLink() {
      return webReaderLink;
    }

    /**
     * URL to read this volume on the Google Books site. Link will not allow users to read non-
     * viewable volumes.
     * The value set may be {@code null}.
     */
    public AccessInfo setWebReaderLink(String webReaderLink) {
      this.webReaderLink = webReaderLink;
      return this;
    }

    /**
     * Information about epub content. (In LITE projection.)
     */
    public static final class Epub extends GenericJson {

      /**
       * URL to retrieve ACS token for epub download. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String acsTokenLink;

      /**
       * URL to download epub. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String downloadLink;

      /**
       * Is a flowing text epub available either as public domain or for purchase. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Boolean isAvailable;

      /**
       * URL to retrieve ACS token for epub download. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public String getAcsTokenLink() {
        return acsTokenLink;
      }

      /**
       * URL to retrieve ACS token for epub download. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public Epub setAcsTokenLink(String acsTokenLink) {
        this.acsTokenLink = acsTokenLink;
        return this;
      }

      /**
       * URL to download epub. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public String getDownloadLink() {
        return downloadLink;
      }

      /**
       * URL to download epub. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public Epub setDownloadLink(String downloadLink) {
        this.downloadLink = downloadLink;
        return this;
      }

      /**
       * Is a flowing text epub available either as public domain or for purchase. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public Boolean getIsAvailable() {
        return isAvailable;
      }

      /**
       * Is a flowing text epub available either as public domain or for purchase. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public Epub setIsAvailable(Boolean isAvailable) {
        this.isAvailable = isAvailable;
        return this;
      }

    }
    /**
     * Information about pdf content. (In LITE projection.)
     */
    public static final class Pdf extends GenericJson {

      /**
       * URL to retrieve ACS token for pdf download. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String acsTokenLink;

      /**
       * URL to download pdf. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String downloadLink;

      /**
       * Is a scanned image pdf available either as public domain or for purchase. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Boolean isAvailable;

      /**
       * URL to retrieve ACS token for pdf download. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public String getAcsTokenLink() {
        return acsTokenLink;
      }

      /**
       * URL to retrieve ACS token for pdf download. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public Pdf setAcsTokenLink(String acsTokenLink) {
        this.acsTokenLink = acsTokenLink;
        return this;
      }

      /**
       * URL to download pdf. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public String getDownloadLink() {
        return downloadLink;
      }

      /**
       * URL to download pdf. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public Pdf setDownloadLink(String downloadLink) {
        this.downloadLink = downloadLink;
        return this;
      }

      /**
       * Is a scanned image pdf available either as public domain or for purchase. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public Boolean getIsAvailable() {
        return isAvailable;
      }

      /**
       * Is a scanned image pdf available either as public domain or for purchase. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public Pdf setIsAvailable(Boolean isAvailable) {
        this.isAvailable = isAvailable;
        return this;
      }

    }
  }

  /**
   * What layers exist in this volume and high level information about them.
   */
  public static final class LayerInfo extends GenericJson {

    /**
     * A layer should appear here if and only if the layer exists for this book.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<Layers> layers;

    static {
      // hack to force ProGuard to consider Layers used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(Layers.class);
    }

    /**
     * A layer should appear here if and only if the layer exists for this book.
     * The value returned may be {@code null}.
     */
    public java.util.List<Layers> getLayers() {
      return layers;
    }

    /**
     * A layer should appear here if and only if the layer exists for this book.
     * The value set may be {@code null}.
     */
    public LayerInfo setLayers(java.util.List<Layers> layers) {
      this.layers = layers;
      return this;
    }

    /**
     * Model definition for VolumeLayerInfoLayers.
     */
    public static final class Layers extends GenericJson {

      /**
       * The layer id of this layer (e.g. "geo").
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String layerId;

      /**
       * The current version of this layer's volume annotations. Note that this version applies only to
       * the data in the books.layers.volumeAnnotations.* responses. The actual annotation data is
       * versioned separately.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String volumeAnnotationsVersion;

      /**
       * The layer id of this layer (e.g. "geo").
       * The value returned may be {@code null}.
       */
      public String getLayerId() {
        return layerId;
      }

      /**
       * The layer id of this layer (e.g. "geo").
       * The value set may be {@code null}.
       */
      public Layers setLayerId(String layerId) {
        this.layerId = layerId;
        return this;
      }

      /**
       * The current version of this layer's volume annotations. Note that this version applies only to
       * the data in the books.layers.volumeAnnotations.* responses. The actual annotation data is
       * versioned separately.
       * The value returned may be {@code null}.
       */
      public String getVolumeAnnotationsVersion() {
        return volumeAnnotationsVersion;
      }

      /**
       * The current version of this layer's volume annotations. Note that this version applies only to
       * the data in the books.layers.volumeAnnotations.* responses. The actual annotation data is
       * versioned separately.
       * The value set may be {@code null}.
       */
      public Layers setVolumeAnnotationsVersion(String volumeAnnotationsVersion) {
        this.volumeAnnotationsVersion = volumeAnnotationsVersion;
        return this;
      }

    }
  }

  /**
   * Recommendation related information for this volume.
   */
  public static final class RecommendedInfo extends GenericJson {

    /**
     * A text explaining why this volume is recommended.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String explanation;

    /**
     * A text explaining why this volume is recommended.
     * The value returned may be {@code null}.
     */
    public String getExplanation() {
      return explanation;
    }

    /**
     * A text explaining why this volume is recommended.
     * The value set may be {@code null}.
     */
    public RecommendedInfo setExplanation(String explanation) {
      this.explanation = explanation;
      return this;
    }

  }

  /**
   * Any information about a volume related to the eBookstore and/or purchaseability. This information
   * can depend on the country where the request originates from (i.e. books may not be for sale in
   * certain countries).
   */
  public static final class SaleInfo extends GenericJson {

    /**
     * URL to purchase this volume on the Google Books site. (In LITE projection)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String buyLink;

    /**
     * The two-letter ISO_3166-1 country code for which this sale information is valid. (In LITE
     * projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String country;

    /**
     * Whether or not this volume is an eBook (can be added to the My eBooks shelf).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean isEbook;

    /**
     * Suggested retail price. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private ListPrice listPrice;

    /**
     * Offers available for this volume (sales and rentals).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<Offers> offers;

    static {
      // hack to force ProGuard to consider Offers used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(Offers.class);
    }

    /**
     * The date on which this book is available for sale.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private DateTime onSaleDate;

    /**
     * The actual selling price of the book. This is the same as the suggested retail or list price
     * unless there are offers or discounts on this volume. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private RetailPrice retailPrice;

    /**
     * Whether or not this book is available for sale or offered for free in the Google eBookstore for
     * the country listed above. Possible values are FOR_SALE, FOR_RENTAL_ONLY, FOR_SALE_AND_RENTAL,
     * FREE, NOT_FOR_SALE, or FOR_PREORDER.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String saleability;

    /**
     * URL to purchase this volume on the Google Books site. (In LITE projection)
     * The value returned may be {@code null}.
     */
    public String getBuyLink() {
      return buyLink;
    }

    /**
     * URL to purchase this volume on the Google Books site. (In LITE projection)
     * The value set may be {@code null}.
     */
    public SaleInfo setBuyLink(String buyLink) {
      this.buyLink = buyLink;
      return this;
    }

    /**
     * The two-letter ISO_3166-1 country code for which this sale information is valid. (In LITE
     * projection.)
     * The value returned may be {@code null}.
     */
    public String getCountry() {
      return country;
    }

    /**
     * The two-letter ISO_3166-1 country code for which this sale information is valid. (In LITE
     * projection.)
     * The value set may be {@code null}.
     */
    public SaleInfo setCountry(String country) {
      this.country = country;
      return this;
    }

    /**
     * Whether or not this volume is an eBook (can be added to the My eBooks shelf).
     * The value returned may be {@code null}.
     */
    public Boolean getIsEbook() {
      return isEbook;
    }

    /**
     * Whether or not this volume is an eBook (can be added to the My eBooks shelf).
     * The value set may be {@code null}.
     */
    public SaleInfo setIsEbook(Boolean isEbook) {
      this.isEbook = isEbook;
      return this;
    }

    /**
     * Suggested retail price. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public ListPrice getListPrice() {
      return listPrice;
    }

    /**
     * Suggested retail price. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public SaleInfo setListPrice(ListPrice listPrice) {
      this.listPrice = listPrice;
      return this;
    }

    /**
     * Offers available for this volume (sales and rentals).
     * The value returned may be {@code null}.
     */
    public java.util.List<Offers> getOffers() {
      return offers;
    }

    /**
     * Offers available for this volume (sales and rentals).
     * The value set may be {@code null}.
     */
    public SaleInfo setOffers(java.util.List<Offers> offers) {
      this.offers = offers;
      return this;
    }

    /**
     * The date on which this book is available for sale.
     * The value returned may be {@code null}.
     */
    public DateTime getOnSaleDate() {
      return onSaleDate;
    }

    /**
     * The date on which this book is available for sale.
     * The value set may be {@code null}.
     */
    public SaleInfo setOnSaleDate(DateTime onSaleDate) {
      this.onSaleDate = onSaleDate;
      return this;
    }

    /**
     * The actual selling price of the book. This is the same as the suggested retail or list price
     * unless there are offers or discounts on this volume. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public RetailPrice getRetailPrice() {
      return retailPrice;
    }

    /**
     * The actual selling price of the book. This is the same as the suggested retail or list price
     * unless there are offers or discounts on this volume. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public SaleInfo setRetailPrice(RetailPrice retailPrice) {
      this.retailPrice = retailPrice;
      return this;
    }

    /**
     * Whether or not this book is available for sale or offered for free in the Google eBookstore for
     * the country listed above. Possible values are FOR_SALE, FOR_RENTAL_ONLY, FOR_SALE_AND_RENTAL,
     * FREE, NOT_FOR_SALE, or FOR_PREORDER.
     * The value returned may be {@code null}.
     */
    public String getSaleability() {
      return saleability;
    }

    /**
     * Whether or not this book is available for sale or offered for free in the Google eBookstore for
     * the country listed above. Possible values are FOR_SALE, FOR_RENTAL_ONLY, FOR_SALE_AND_RENTAL,
     * FREE, NOT_FOR_SALE, or FOR_PREORDER.
     * The value set may be {@code null}.
     */
    public SaleInfo setSaleability(String saleability) {
      this.saleability = saleability;
      return this;
    }

    /**
     * Suggested retail price. (In LITE projection.)
     */
    public static final class ListPrice extends GenericJson {

      /**
       * Amount in the currency listed below. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Double amount;

      /**
       * An ISO 4217, three-letter currency code. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String currencyCode;

      /**
       * Amount in the currency listed below. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public Double getAmount() {
        return amount;
      }

      /**
       * Amount in the currency listed below. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public ListPrice setAmount(Double amount) {
        this.amount = amount;
        return this;
      }

      /**
       * An ISO 4217, three-letter currency code. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public String getCurrencyCode() {
        return currencyCode;
      }

      /**
       * An ISO 4217, three-letter currency code. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public ListPrice setCurrencyCode(String currencyCode) {
        this.currencyCode = currencyCode;
        return this;
      }

    }
    /**
     * Model definition for VolumeSaleInfoOffers.
     */
    public static final class Offers extends GenericJson {

      /**
       * The finsky offer type (e.g., PURCHASE=0 RENTAL=3)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Integer finskyOfferType;

      /**
       * Offer list (=undiscounted) price in Micros.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private ListPrice listPrice;

      /**
       * The rental duration (for rental offers only).
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private RentalDuration rentalDuration;

      /**
       * Offer retail (=discounted) price in Micros
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private RetailPrice retailPrice;

      /**
       * The finsky offer type (e.g., PURCHASE=0 RENTAL=3)
       * The value returned may be {@code null}.
       */
      public Integer getFinskyOfferType() {
        return finskyOfferType;
      }

      /**
       * The finsky offer type (e.g., PURCHASE=0 RENTAL=3)
       * The value set may be {@code null}.
       */
      public Offers setFinskyOfferType(Integer finskyOfferType) {
        this.finskyOfferType = finskyOfferType;
        return this;
      }

      /**
       * Offer list (=undiscounted) price in Micros.
       * The value returned may be {@code null}.
       */
      public ListPrice getListPrice() {
        return listPrice;
      }

      /**
       * Offer list (=undiscounted) price in Micros.
       * The value set may be {@code null}.
       */
      public Offers setListPrice(ListPrice listPrice) {
        this.listPrice = listPrice;
        return this;
      }

      /**
       * The rental duration (for rental offers only).
       * The value returned may be {@code null}.
       */
      public RentalDuration getRentalDuration() {
        return rentalDuration;
      }

      /**
       * The rental duration (for rental offers only).
       * The value set may be {@code null}.
       */
      public Offers setRentalDuration(RentalDuration rentalDuration) {
        this.rentalDuration = rentalDuration;
        return this;
      }

      /**
       * Offer retail (=discounted) price in Micros
       * The value returned may be {@code null}.
       */
      public RetailPrice getRetailPrice() {
        return retailPrice;
      }

      /**
       * Offer retail (=discounted) price in Micros
       * The value set may be {@code null}.
       */
      public Offers setRetailPrice(RetailPrice retailPrice) {
        this.retailPrice = retailPrice;
        return this;
      }

      /**
       * Offer list (=undiscounted) price in Micros.
       */
      public static final class ListPrice extends GenericJson {

        /**
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private Double amountInMicros;

        /**
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String currencyCode;

        /**

         * The value returned may be {@code null}.
         */
        public Double getAmountInMicros() {
          return amountInMicros;
        }

        /**

         * The value set may be {@code null}.
         */
        public ListPrice setAmountInMicros(Double amountInMicros) {
          this.amountInMicros = amountInMicros;
          return this;
        }

        /**

         * The value returned may be {@code null}.
         */
        public String getCurrencyCode() {
          return currencyCode;
        }

        /**

         * The value set may be {@code null}.
         */
        public ListPrice setCurrencyCode(String currencyCode) {
          this.currencyCode = currencyCode;
          return this;
        }

      }
      /**
       * The rental duration (for rental offers only).
       */
      public static final class RentalDuration extends GenericJson {

        /**
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private Double count;

        /**
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String unit;

        /**

         * The value returned may be {@code null}.
         */
        public Double getCount() {
          return count;
        }

        /**

         * The value set may be {@code null}.
         */
        public RentalDuration setCount(Double count) {
          this.count = count;
          return this;
        }

        /**

         * The value returned may be {@code null}.
         */
        public String getUnit() {
          return unit;
        }

        /**

         * The value set may be {@code null}.
         */
        public RentalDuration setUnit(String unit) {
          this.unit = unit;
          return this;
        }

      }
      /**
       * Offer retail (=discounted) price in Micros
       */
      public static final class RetailPrice extends GenericJson {

        /**
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private Double amountInMicros;

        /**
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String currencyCode;

        /**

         * The value returned may be {@code null}.
         */
        public Double getAmountInMicros() {
          return amountInMicros;
        }

        /**

         * The value set may be {@code null}.
         */
        public RetailPrice setAmountInMicros(Double amountInMicros) {
          this.amountInMicros = amountInMicros;
          return this;
        }

        /**

         * The value returned may be {@code null}.
         */
        public String getCurrencyCode() {
          return currencyCode;
        }

        /**

         * The value set may be {@code null}.
         */
        public RetailPrice setCurrencyCode(String currencyCode) {
          this.currencyCode = currencyCode;
          return this;
        }

      }
    }
    /**
     * The actual selling price of the book. This is the same as the suggested retail or list price
     * unless there are offers or discounts on this volume. (In LITE projection.)
     */
    public static final class RetailPrice extends GenericJson {

      /**
       * Amount in the currency listed below. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Double amount;

      /**
       * An ISO 4217, three-letter currency code. (In LITE projection.)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String currencyCode;

      /**
       * Amount in the currency listed below. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public Double getAmount() {
        return amount;
      }

      /**
       * Amount in the currency listed below. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public RetailPrice setAmount(Double amount) {
        this.amount = amount;
        return this;
      }

      /**
       * An ISO 4217, three-letter currency code. (In LITE projection.)
       * The value returned may be {@code null}.
       */
      public String getCurrencyCode() {
        return currencyCode;
      }

      /**
       * An ISO 4217, three-letter currency code. (In LITE projection.)
       * The value set may be {@code null}.
       */
      public RetailPrice setCurrencyCode(String currencyCode) {
        this.currencyCode = currencyCode;
        return this;
      }

    }
  }

  /**
   * Search result information related to this volume.
   */
  public static final class SearchInfo extends GenericJson {

    /**
     * A text snippet containing the search query.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String textSnippet;

    /**
     * A text snippet containing the search query.
     * The value returned may be {@code null}.
     */
    public String getTextSnippet() {
      return textSnippet;
    }

    /**
     * A text snippet containing the search query.
     * The value set may be {@code null}.
     */
    public SearchInfo setTextSnippet(String textSnippet) {
      this.textSnippet = textSnippet;
      return this;
    }

  }

  /**
   * User specific information related to this volume. (e.g. page this user last read or whether they
   * purchased this book)
   */
  public static final class UserInfo extends GenericJson {

    /**
     * Copy/Paste accounting information.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Copy copy;

    /**
     * Whether or not this volume is currently in "my books."
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean isInMyBooks;

    /**
     * Whether or not this volume was pre-ordered by the authenticated user making the request. (In
     * LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean isPreordered;

    /**
     * Whether or not this volume was purchased by the authenticated user making the request. (In LITE
     * projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean isPurchased;

    /**
     * Whether or not this volume was user uploaded.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean isUploaded;

    /**
     * The user's current reading position in the volume, if one is available. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private ReadingPosition readingPosition;

    /**
     * Period during this book is/was a valid rental.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private RentalPeriod rentalPeriod;

    /**
     * Whether this book is an active or an expired rental.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String rentalState;

    /**
     * This user's review of this volume, if one exists.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Review review;

    /**
     * Timestamp when this volume was last modified by a user action, such as a reading position
     * update, volume purchase or writing a review. (RFC 3339 UTC date-time format).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private DateTime updated;

    /**
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private UserUploadedVolumeInfo userUploadedVolumeInfo;

    /**
     * Copy/Paste accounting information.
     * The value returned may be {@code null}.
     */
    public Copy getCopy() {
      return copy;
    }

    /**
     * Copy/Paste accounting information.
     * The value set may be {@code null}.
     */
    public UserInfo setCopy(Copy copy) {
      this.copy = copy;
      return this;
    }

    /**
     * Whether or not this volume is currently in "my books."
     * The value returned may be {@code null}.
     */
    public Boolean getIsInMyBooks() {
      return isInMyBooks;
    }

    /**
     * Whether or not this volume is currently in "my books."
     * The value set may be {@code null}.
     */
    public UserInfo setIsInMyBooks(Boolean isInMyBooks) {
      this.isInMyBooks = isInMyBooks;
      return this;
    }

    /**
     * Whether or not this volume was pre-ordered by the authenticated user making the request. (In
     * LITE projection.)
     * The value returned may be {@code null}.
     */
    public Boolean getIsPreordered() {
      return isPreordered;
    }

    /**
     * Whether or not this volume was pre-ordered by the authenticated user making the request. (In
     * LITE projection.)
     * The value set may be {@code null}.
     */
    public UserInfo setIsPreordered(Boolean isPreordered) {
      this.isPreordered = isPreordered;
      return this;
    }

    /**
     * Whether or not this volume was purchased by the authenticated user making the request. (In LITE
     * projection.)
     * The value returned may be {@code null}.
     */
    public Boolean getIsPurchased() {
      return isPurchased;
    }

    /**
     * Whether or not this volume was purchased by the authenticated user making the request. (In LITE
     * projection.)
     * The value set may be {@code null}.
     */
    public UserInfo setIsPurchased(Boolean isPurchased) {
      this.isPurchased = isPurchased;
      return this;
    }

    /**
     * Whether or not this volume was user uploaded.
     * The value returned may be {@code null}.
     */
    public Boolean getIsUploaded() {
      return isUploaded;
    }

    /**
     * Whether or not this volume was user uploaded.
     * The value set may be {@code null}.
     */
    public UserInfo setIsUploaded(Boolean isUploaded) {
      this.isUploaded = isUploaded;
      return this;
    }

    /**
     * The user's current reading position in the volume, if one is available. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public ReadingPosition getReadingPosition() {
      return readingPosition;
    }

    /**
     * The user's current reading position in the volume, if one is available. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public UserInfo setReadingPosition(ReadingPosition readingPosition) {
      this.readingPosition = readingPosition;
      return this;
    }

    /**
     * Period during this book is/was a valid rental.
     * The value returned may be {@code null}.
     */
    public RentalPeriod getRentalPeriod() {
      return rentalPeriod;
    }

    /**
     * Period during this book is/was a valid rental.
     * The value set may be {@code null}.
     */
    public UserInfo setRentalPeriod(RentalPeriod rentalPeriod) {
      this.rentalPeriod = rentalPeriod;
      return this;
    }

    /**
     * Whether this book is an active or an expired rental.
     * The value returned may be {@code null}.
     */
    public String getRentalState() {
      return rentalState;
    }

    /**
     * Whether this book is an active or an expired rental.
     * The value set may be {@code null}.
     */
    public UserInfo setRentalState(String rentalState) {
      this.rentalState = rentalState;
      return this;
    }

    /**
     * This user's review of this volume, if one exists.
     * The value returned may be {@code null}.
     */
    public Review getReview() {
      return review;
    }

    /**
     * This user's review of this volume, if one exists.
     * The value set may be {@code null}.
     */
    public UserInfo setReview(Review review) {
      this.review = review;
      return this;
    }

    /**
     * Timestamp when this volume was last modified by a user action, such as a reading position
     * update, volume purchase or writing a review. (RFC 3339 UTC date-time format).
     * The value returned may be {@code null}.
     */
    public DateTime getUpdated() {
      return updated;
    }

    /**
     * Timestamp when this volume was last modified by a user action, such as a reading position
     * update, volume purchase or writing a review. (RFC 3339 UTC date-time format).
     * The value set may be {@code null}.
     */
    public UserInfo setUpdated(DateTime updated) {
      this.updated = updated;
      return this;
    }

    /**

     * The value returned may be {@code null}.
     */
    public UserUploadedVolumeInfo getUserUploadedVolumeInfo() {
      return userUploadedVolumeInfo;
    }

    /**

     * The value set may be {@code null}.
     */
    public UserInfo setUserUploadedVolumeInfo(UserUploadedVolumeInfo userUploadedVolumeInfo) {
      this.userUploadedVolumeInfo = userUploadedVolumeInfo;
      return this;
    }

    /**
     * Copy/Paste accounting information.
     */
    public static final class Copy extends GenericJson {

      /**
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Integer allowedCharacterCount;

      /**
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String limitType;

      /**
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Integer remainingCharacterCount;

      /**
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private DateTime updated;

      /**

       * The value returned may be {@code null}.
       */
      public Integer getAllowedCharacterCount() {
        return allowedCharacterCount;
      }

      /**

       * The value set may be {@code null}.
       */
      public Copy setAllowedCharacterCount(Integer allowedCharacterCount) {
        this.allowedCharacterCount = allowedCharacterCount;
        return this;
      }

      /**

       * The value returned may be {@code null}.
       */
      public String getLimitType() {
        return limitType;
      }

      /**

       * The value set may be {@code null}.
       */
      public Copy setLimitType(String limitType) {
        this.limitType = limitType;
        return this;
      }

      /**

       * The value returned may be {@code null}.
       */
      public Integer getRemainingCharacterCount() {
        return remainingCharacterCount;
      }

      /**

       * The value set may be {@code null}.
       */
      public Copy setRemainingCharacterCount(Integer remainingCharacterCount) {
        this.remainingCharacterCount = remainingCharacterCount;
        return this;
      }

      /**

       * The value returned may be {@code null}.
       */
      public DateTime getUpdated() {
        return updated;
      }

      /**

       * The value set may be {@code null}.
       */
      public Copy setUpdated(DateTime updated) {
        this.updated = updated;
        return this;
      }

    }
    /**
     * Period during this book is/was a valid rental.
     */
    public static final class RentalPeriod extends GenericJson {

      /**
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key @JsonString
      private Long endUtcSec;

      /**
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key @JsonString
      private Long startUtcSec;

      /**

       * The value returned may be {@code null}.
       */
      public Long getEndUtcSec() {
        return endUtcSec;
      }

      /**

       * The value set may be {@code null}.
       */
      public RentalPeriod setEndUtcSec(Long endUtcSec) {
        this.endUtcSec = endUtcSec;
        return this;
      }

      /**

       * The value returned may be {@code null}.
       */
      public Long getStartUtcSec() {
        return startUtcSec;
      }

      /**

       * The value set may be {@code null}.
       */
      public RentalPeriod setStartUtcSec(Long startUtcSec) {
        this.startUtcSec = startUtcSec;
        return this;
      }

    }
    /**
     * Model definition for VolumeUserInfoUserUploadedVolumeInfo.
     */
    public static final class UserUploadedVolumeInfo extends GenericJson {

      /**
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String processingState;

      /**

       * The value returned may be {@code null}.
       */
      public String getProcessingState() {
        return processingState;
      }

      /**

       * The value set may be {@code null}.
       */
      public UserUploadedVolumeInfo setProcessingState(String processingState) {
        this.processingState = processingState;
        return this;
      }

    }
  }

  /**
   * General volume information.
   */
  public static final class VolumeInfo extends GenericJson {

    /**
     * The names of the authors and/or editors for this volume. (In LITE projection)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> authors;

    /**
     * The mean review rating for this volume. (min = 1.0, max = 5.0)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Double averageRating;

    /**
     * Canonical URL for a volume. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String canonicalVolumeLink;

    /**
     * A list of subject categories, such as "Fiction", "Suspense", etc.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> categories;

    /**
     * An identifier for the version of the volume content (text & images). (In LITE projection)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String contentVersion;

    /**
     * A synopsis of the volume. The text of the description is formatted in HTML and includes simple
     * formatting elements, such as b, i, and br tags. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String description;

    /**
     * Physical dimensions of this volume.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Dimensions dimensions;

    /**
     * A list of image links for all the sizes that are available. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private ImageLinks imageLinks;

    /**
     * Industry standard identifiers for this volume.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<IndustryIdentifiers> industryIdentifiers;

    static {
      // hack to force ProGuard to consider IndustryIdentifiers used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(IndustryIdentifiers.class);
    }

    /**
     * URL to view information about this volume on the Google Books site. (In LITE projection)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String infoLink;

    /**
     * Best language for this volume (based on content). It is the two-letter ISO 639-1 code such as
     * 'fr', 'en', etc.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String language;

    /**
     * The main category to which this volume belongs. It will be the category from the categories
     * list returned below that has the highest weight.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String mainCategory;

    /**
     * Total number of pages.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer pageCount;

    /**
     * URL to preview this volume on the Google Books site.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String previewLink;

    /**
     * Type of publication of this volume. Possible values are BOOK or MAGAZINE.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String printType;

    /**
     * Date of publication. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String publishedDate;

    /**
     * Publisher of this volume. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String publisher;

    /**
     * The number of review ratings for this volume.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer ratingsCount;

    /**
     * Volume subtitle. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String subtitle;

    /**
     * Volume title. (In LITE projection.)
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String title;

    /**
     * The names of the authors and/or editors for this volume. (In LITE projection)
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getAuthors() {
      return authors;
    }

    /**
     * The names of the authors and/or editors for this volume. (In LITE projection)
     * The value set may be {@code null}.
     */
    public VolumeInfo setAuthors(java.util.List<String> authors) {
      this.authors = authors;
      return this;
    }

    /**
     * The mean review rating for this volume. (min = 1.0, max = 5.0)
     * The value returned may be {@code null}.
     */
    public Double getAverageRating() {
      return averageRating;
    }

    /**
     * The mean review rating for this volume. (min = 1.0, max = 5.0)
     * The value set may be {@code null}.
     */
    public VolumeInfo setAverageRating(Double averageRating) {
      this.averageRating = averageRating;
      return this;
    }

    /**
     * Canonical URL for a volume. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public String getCanonicalVolumeLink() {
      return canonicalVolumeLink;
    }

    /**
     * Canonical URL for a volume. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public VolumeInfo setCanonicalVolumeLink(String canonicalVolumeLink) {
      this.canonicalVolumeLink = canonicalVolumeLink;
      return this;
    }

    /**
     * A list of subject categories, such as "Fiction", "Suspense", etc.
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getCategories() {
      return categories;
    }

    /**
     * A list of subject categories, such as "Fiction", "Suspense", etc.
     * The value set may be {@code null}.
     */
    public VolumeInfo setCategories(java.util.List<String> categories) {
      this.categories = categories;
      return this;
    }

    /**
     * An identifier for the version of the volume content (text & images). (In LITE projection)
     * The value returned may be {@code null}.
     */
    public String getContentVersion() {
      return contentVersion;
    }

    /**
     * An identifier for the version of the volume content (text & images). (In LITE projection)
     * The value set may be {@code null}.
     */
    public VolumeInfo setContentVersion(String contentVersion) {
      this.contentVersion = contentVersion;
      return this;
    }

    /**
     * A synopsis of the volume. The text of the description is formatted in HTML and includes simple
     * formatting elements, such as b, i, and br tags. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public String getDescription() {
      return description;
    }

    /**
     * A synopsis of the volume. The text of the description is formatted in HTML and includes simple
     * formatting elements, such as b, i, and br tags. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public VolumeInfo setDescription(String description) {
      this.description = description;
      return this;
    }

    /**
     * Physical dimensions of this volume.
     * The value returned may be {@code null}.
     */
    public Dimensions getDimensions() {
      return dimensions;
    }

    /**
     * Physical dimensions of this volume.
     * The value set may be {@code null}.
     */
    public VolumeInfo setDimensions(Dimensions dimensions) {
      this.dimensions = dimensions;
      return this;
    }

    /**
     * A list of image links for all the sizes that are available. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public ImageLinks getImageLinks() {
      return imageLinks;
    }

    /**
     * A list of image links for all the sizes that are available. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public VolumeInfo setImageLinks(ImageLinks imageLinks) {
      this.imageLinks = imageLinks;
      return this;
    }

    /**
     * Industry standard identifiers for this volume.
     * The value returned may be {@code null}.
     */
    public java.util.List<IndustryIdentifiers> getIndustryIdentifiers() {
      return industryIdentifiers;
    }

    /**
     * Industry standard identifiers for this volume.
     * The value set may be {@code null}.
     */
    public VolumeInfo setIndustryIdentifiers(java.util.List<IndustryIdentifiers> industryIdentifiers) {
      this.industryIdentifiers = industryIdentifiers;
      return this;
    }

    /**
     * URL to view information about this volume on the Google Books site. (In LITE projection)
     * The value returned may be {@code null}.
     */
    public String getInfoLink() {
      return infoLink;
    }

    /**
     * URL to view information about this volume on the Google Books site. (In LITE projection)
     * The value set may be {@code null}.
     */
    public VolumeInfo setInfoLink(String infoLink) {
      this.infoLink = infoLink;
      return this;
    }

    /**
     * Best language for this volume (based on content). It is the two-letter ISO 639-1 code such as
     * 'fr', 'en', etc.
     * The value returned may be {@code null}.
     */
    public String getLanguage() {
      return language;
    }

    /**
     * Best language for this volume (based on content). It is the two-letter ISO 639-1 code such as
     * 'fr', 'en', etc.
     * The value set may be {@code null}.
     */
    public VolumeInfo setLanguage(String language) {
      this.language = language;
      return this;
    }

    /**
     * The main category to which this volume belongs. It will be the category from the categories
     * list returned below that has the highest weight.
     * The value returned may be {@code null}.
     */
    public String getMainCategory() {
      return mainCategory;
    }

    /**
     * The main category to which this volume belongs. It will be the category from the categories
     * list returned below that has the highest weight.
     * The value set may be {@code null}.
     */
    public VolumeInfo setMainCategory(String mainCategory) {
      this.mainCategory = mainCategory;
      return this;
    }

    /**
     * Total number of pages.
     * The value returned may be {@code null}.
     */
    public Integer getPageCount() {
      return pageCount;
    }

    /**
     * Total number of pages.
     * The value set may be {@code null}.
     */
    public VolumeInfo setPageCount(Integer pageCount) {
      this.pageCount = pageCount;
      return this;
    }

    /**
     * URL to preview this volume on the Google Books site.
     * The value returned may be {@code null}.
     */
    public String getPreviewLink() {
      return previewLink;
    }

    /**
     * URL to preview this volume on the Google Books site.
     * The value set may be {@code null}.
     */
    public VolumeInfo setPreviewLink(String previewLink) {
      this.previewLink = previewLink;
      return this;
    }

    /**
     * Type of publication of this volume. Possible values are BOOK or MAGAZINE.
     * The value returned may be {@code null}.
     */
    public String getPrintType() {
      return printType;
    }

    /**
     * Type of publication of this volume. Possible values are BOOK or MAGAZINE.
     * The value set may be {@code null}.
     */
    public VolumeInfo setPrintType(String printType) {
      this.printType = printType;
      return this;
    }

    /**
     * Date of publication. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public String getPublishedDate() {
      return publishedDate;
    }

    /**
     * Date of publication. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public VolumeInfo setPublishedDate(String publishedDate) {
      this.publishedDate = publishedDate;
      return this;
    }

    /**
     * Publisher of this volume. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public String getPublisher() {
      return publisher;
    }

    /**
     * Publisher of this volume. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public VolumeInfo setPublisher(String publisher) {
      this.publisher = publisher;
      return this;
    }

    /**
     * The number of review ratings for this volume.
     * The value returned may be {@code null}.
     */
    public Integer getRatingsCount() {
      return ratingsCount;
    }

    /**
     * The number of review ratings for this volume.
     * The value set may be {@code null}.
     */
    public VolumeInfo setRatingsCount(Integer ratingsCount) {
      this.ratingsCount = ratingsCount;
      return this;
    }

    /**
     * Volume subtitle. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public String getSubtitle() {
      return subtitle;
    }

    /**
     * Volume subtitle. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public VolumeInfo setSubtitle(String subtitle) {
      this.subtitle = subtitle;
      return this;
    }

    /**
     * Volume title. (In LITE projection.)
     * The value returned may be {@code null}.
     */
    public String getTitle() {
      return title;
    }

    /**
     * Volume title. (In LITE projection.)
     * The value set may be {@code null}.
     */
    public VolumeInfo setTitle(String title) {
      this.title = title;
      return this;
    }

    /**
     * Physical dimensions of this volume.
     */
    public static final class Dimensions extends GenericJson {

      /**
       * Height or length of this volume (in cm).
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String height;

      /**
       * Thickness of this volume (in cm).
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String thickness;

      /**
       * Width of this volume (in cm).
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String width;

      /**
       * Height or length of this volume (in cm).
       * The value returned may be {@code null}.
       */
      public String getHeight() {
        return height;
      }

      /**
       * Height or length of this volume (in cm).
       * The value set may be {@code null}.
       */
      public Dimensions setHeight(String height) {
        this.height = height;
        return this;
      }

      /**
       * Thickness of this volume (in cm).
       * The value returned may be {@code null}.
       */
      public String getThickness() {
        return thickness;
      }

      /**
       * Thickness of this volume (in cm).
       * The value set may be {@code null}.
       */
      public Dimensions setThickness(String thickness) {
        this.thickness = thickness;
        return this;
      }

      /**
       * Width of this volume (in cm).
       * The value returned may be {@code null}.
       */
      public String getWidth() {
        return width;
      }

      /**
       * Width of this volume (in cm).
       * The value set may be {@code null}.
       */
      public Dimensions setWidth(String width) {
        this.width = width;
        return this;
      }

    }
    /**
     * A list of image links for all the sizes that are available. (In LITE projection.)
     */
    public static final class ImageLinks extends GenericJson {

      /**
       * Image link for extra large size (width of ~1280 pixels). (In LITE projection)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String extraLarge;

      /**
       * Image link for large size (width of ~800 pixels). (In LITE projection)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String large;

      /**
       * Image link for medium size (width of ~575 pixels). (In LITE projection)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String medium;

      /**
       * Image link for small size (width of ~300 pixels). (In LITE projection)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String small;

      /**
       * Image link for small thumbnail size (width of ~80 pixels). (In LITE projection)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String smallThumbnail;

      /**
       * Image link for thumbnail size (width of ~128 pixels). (In LITE projection)
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String thumbnail;

      /**
       * Image link for extra large size (width of ~1280 pixels). (In LITE projection)
       * The value returned may be {@code null}.
       */
      public String getExtraLarge() {
        return extraLarge;
      }

      /**
       * Image link for extra large size (width of ~1280 pixels). (In LITE projection)
       * The value set may be {@code null}.
       */
      public ImageLinks setExtraLarge(String extraLarge) {
        this.extraLarge = extraLarge;
        return this;
      }

      /**
       * Image link for large size (width of ~800 pixels). (In LITE projection)
       * The value returned may be {@code null}.
       */
      public String getLarge() {
        return large;
      }

      /**
       * Image link for large size (width of ~800 pixels). (In LITE projection)
       * The value set may be {@code null}.
       */
      public ImageLinks setLarge(String large) {
        this.large = large;
        return this;
      }

      /**
       * Image link for medium size (width of ~575 pixels). (In LITE projection)
       * The value returned may be {@code null}.
       */
      public String getMedium() {
        return medium;
      }

      /**
       * Image link for medium size (width of ~575 pixels). (In LITE projection)
       * The value set may be {@code null}.
       */
      public ImageLinks setMedium(String medium) {
        this.medium = medium;
        return this;
      }

      /**
       * Image link for small size (width of ~300 pixels). (In LITE projection)
       * The value returned may be {@code null}.
       */
      public String getSmall() {
        return small;
      }

      /**
       * Image link for small size (width of ~300 pixels). (In LITE projection)
       * The value set may be {@code null}.
       */
      public ImageLinks setSmall(String small) {
        this.small = small;
        return this;
      }

      /**
       * Image link for small thumbnail size (width of ~80 pixels). (In LITE projection)
       * The value returned may be {@code null}.
       */
      public String getSmallThumbnail() {
        return smallThumbnail;
      }

      /**
       * Image link for small thumbnail size (width of ~80 pixels). (In LITE projection)
       * The value set may be {@code null}.
       */
      public ImageLinks setSmallThumbnail(String smallThumbnail) {
        this.smallThumbnail = smallThumbnail;
        return this;
      }

      /**
       * Image link for thumbnail size (width of ~128 pixels). (In LITE projection)
       * The value returned may be {@code null}.
       */
      public String getThumbnail() {
        return thumbnail;
      }

      /**
       * Image link for thumbnail size (width of ~128 pixels). (In LITE projection)
       * The value set may be {@code null}.
       */
      public ImageLinks setThumbnail(String thumbnail) {
        this.thumbnail = thumbnail;
        return this;
      }

    }
    /**
     * Model definition for VolumeVolumeInfoIndustryIdentifiers.
     */
    public static final class IndustryIdentifiers extends GenericJson {

      /**
       * Industry specific volume identifier.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String identifier;

      /**
       * Identifier type. Possible values are ISBN_10, ISBN_13, ISSN and OTHER.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String type;

      /**
       * Industry specific volume identifier.
       * The value returned may be {@code null}.
       */
      public String getIdentifier() {
        return identifier;
      }

      /**
       * Industry specific volume identifier.
       * The value set may be {@code null}.
       */
      public IndustryIdentifiers setIdentifier(String identifier) {
        this.identifier = identifier;
        return this;
      }

      /**
       * Identifier type. Possible values are ISBN_10, ISBN_13, ISSN and OTHER.
       * The value returned may be {@code null}.
       */
      public String getType() {
        return type;
      }

      /**
       * Identifier type. Possible values are ISBN_10, ISBN_13, ISSN and OTHER.
       * The value set may be {@code null}.
       */
      public IndustryIdentifiers setType(String type) {
        this.type = type;
        return this;
      }

    }
  }
}
